@@ -2,14 +2,17 @@
 function (obj) 
 {
     if (class(obj) == "noia.linear") {
-        g <- cbind(obj$S %*% obj$E, sqrt((obj$S * obj$S) %*% 
+        if (is.null(obj$smat)) {
+            stop("No GP map estimate with 'fast' algorith")
+        }
+        g <- cbind(obj$smat %*% obj$E, sqrt((obj$smat * obj$smat) %*% 
             (obj$std.dev * obj$std.dev)))
         colnames(g) <- c("G.val", "std.err")
         return(g)
     }
     else if (class(obj) == "noia.multilinear") {
         rec <- reconstructLinearEffects(obj)
-        g <- cbind(obj$S %*% rec[, 1], sqrt((obj$S * obj$S) %*% 
+        g <- cbind(obj$smat %*% rec[, 1], sqrt((obj$smat * obj$smat) %*% 
             (rec[, 2] * rec[, 2])))
         return(g)
     }
